@@ -1,4 +1,4 @@
-# Copyright (c) 2021 K.M Ahnaf Zamil
+# Copyright (c) 2021 DevGuyAhnaf
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -19,11 +19,16 @@
 # SOFTWARE.
 
 CDN_URL = "https://cdn.discordapp.com"
-BASE_URL = "https://discord.com/api/v8"
+BASE_URL = "https://discord.com/api/v9"
 
 # CDN Endpoints
 USER_AVATAR = "/avatars"
 
+# Oauth
+OAUTH_TOKEN_URL = "/oauth2/token"
+
 # Users
 GET_CURRENT_USER = "/users/@me"
 GET_USER = "/users/{}"
+GET_USER_CONNECTIONS = GET_CURRENT_USER + "/connections"
+DM_URL = GET_CURRENT_USER + "/channels"
